"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
//#region IMPORTS
var enums_1 = require("./utils/enums");
exports.ELoglevel = enums_1.ELoglevel;
exports.ETransportType = enums_1.ETransportType;
exports.EConsoleType = enums_1.EConsoleType;
var transport_1 = require("./lib/transport");
exports.DefaultConsolTransport = transport_1.DefaultConsolTransport;
exports.DefaultFsTransport = transport_1.DefaultFsTransport;
exports.BaseTransport = transport_1.BaseTransport;
var fs = require("fs");
//#endregion
var Logger = /** @class */ (function () {
    function Logger(config) {
        this.config = this.setConfig(config);
        for (var _i = 0, _a = this.config.transports; _i < _a.length; _i++) {
            var transport = _a[_i];
            switch (transport.type) {
                case enums_1.ETransportType.filesystem:
                    this.initializeFsLogger(transport);
                    break;
                case enums_1.ETransportType.console:
                    // no initialising required
                    break;
            }
        }
    }
    //#region public functions
    Logger.prototype.trace = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        var output = this.configureOutput(args, enums_1.ELoglevel.TRACE, this.config.transports[0]);
        this.writeLog(output, enums_1.ELoglevel.TRACE, enums_1.EConsoleType.log);
        return output;
    };
    Logger.prototype.debug = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        var output = this.configureOutput(args, enums_1.ELoglevel.DEBUG, this.config.transports[0]);
        this.writeLog(output, enums_1.ELoglevel.DEBUG, enums_1.EConsoleType.log);
        return output;
    };
    Logger.prototype.info = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        var output = this.configureOutput(args, enums_1.ELoglevel.INFO, this.config.transports[0]);
        this.writeLog(output, enums_1.ELoglevel.INFO, enums_1.EConsoleType.log);
        return output;
    };
    Logger.prototype.warn = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        var output = this.configureOutput(args, enums_1.ELoglevel.WARN, this.config.transports[0]);
        this.writeLog(output, enums_1.ELoglevel.WARN, enums_1.EConsoleType.warn);
        return output;
    };
    Logger.prototype.error = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        var output = this.configureOutput(args, enums_1.ELoglevel.ERROR, this.config.transports[0]);
        this.writeLog(output, enums_1.ELoglevel.ERROR, enums_1.EConsoleType.error);
        return output;
    };
    //#endregion
    //#region private functions
    Logger.prototype.writeLog = function (input, loglevel, logType) {
        for (var _i = 0, _a = this.config.transports; _i < _a.length; _i++) {
            var transport = _a[_i];
            if (loglevel >= transport.loglvl) {
                switch (transport.type) {
                    case enums_1.ETransportType.filesystem:
                        this.writeTypeFilesystem(input, transport.logpath);
                        break;
                    default:
                        this.writeTypeConsole(input, logType);
                        break;
                }
            }
        }
    };
    Logger.prototype.writeTypeFilesystem = function (input, path) {
        this.stream.write(input + "\r\n");
    };
    Logger.prototype.writeTypeConsole = function (input, logType) {
        switch (logType) {
            case enums_1.EConsoleType.warn:
                console.warn(input);
                break;
            case enums_1.EConsoleType.error:
                console.error(input);
                break;
            default:
                console.log(input);
                break;
        }
    };
    Logger.prototype.initializeFsLogger = function (transport) {
        try {
            var logPath = transport.logpath;
            var folders = logPath.split("/");
            var rootPath = folders[0];
            folders.shift();
            rootPath = rootPath === "%appdata%" ? process.env.appdata : rootPath;
            for (var _i = 0, folders_1 = folders; _i < folders_1.length; _i++) {
                var folder = folders_1[_i];
                rootPath += "\\" + folder;
                if (!fs.existsSync(rootPath)) {
                    fs.mkdirSync(rootPath);
                }
            }
            logPath = logPath.replace("%appdata%", process.env.appdata);
            this.stream = fs.createWriteStream(logPath + "\\" + transport.logFileName + ".log", { flags: "a" });
        }
        catch (error) {
            console.error("error in createWriteStream", error);
        }
    };
    Logger.prototype.setConfig = function (config) {
        var mergedConfig = {
            transports: []
        };
        try {
            if (typeof (config) === "undefined") {
                var defaultTransportConsol = new transport_1.DefaultConsolTransport();
                mergedConfig.transports.push(defaultTransportConsol);
                return mergedConfig;
            }
            if (config.transports.length === 0) {
                var defaultTransportConsol = new transport_1.DefaultConsolTransport();
                defaultTransportConsol.baseComment = config.baseComment ? config.baseComment : defaultTransportConsol.baseComment;
                defaultTransportConsol.loglvl = typeof (config.loglvl) !== "undefined" ? config.loglvl : defaultTransportConsol.loglvl;
                mergedConfig.transports.push(defaultTransportConsol);
                return mergedConfig;
            }
            for (var _i = 0, _a = config.transports; _i < _a.length; _i++) {
                var transport = _a[_i];
                var mergedTransport = new transport_1.BaseTransport();
                var base = transport.baseComment ? transport.baseComment : (config.baseComment ? config.baseComment : null);
                var loglvl = typeof (transport.loglvl) !== "undefined" ? transport.loglvl :
                    (typeof (config.loglvl) !== "undefined" ? config.loglvl : null);
                mergedTransport.baseComment = base === null ? mergedTransport.baseComment : base;
                mergedTransport.loglvl = loglvl === null ? mergedTransport.loglvl : loglvl;
                mergedTransport.showBaseComment = transport.showBaseComment ? transport.showBaseComment : mergedTransport.showBaseComment;
                mergedTransport.showDate = transport.showDate ? transport.showDate : mergedTransport.showDate;
                mergedTransport.showLoglevel = transport.showLoglevel ? transport.showLoglevel : mergedTransport.showLoglevel;
                switch (transport.type) {
                    case enums_1.ETransportType.filesystem:
                        mergedTransport = new transport_1.DefaultFsTransport(mergedTransport);
                        mergedTransport.logpath = transport.logpath
                            ? transport.logpath : mergedTransport.logpath;
                        mergedTransport.logFileName = transport.logFileName
                            ? transport.logFileName : mergedTransport.logFileName;
                        break;
                    default:
                        mergedTransport = new transport_1.DefaultConsolTransport(mergedTransport);
                        break;
                }
                mergedConfig.transports.push(mergedTransport);
            }
        }
        catch (error) {
            console.error("error in set Config of Logger: ", error);
        }
        return mergedConfig;
    };
    Logger.prototype.configureOutput = function (args, loglevel, transport) {
        try {
            var returnString = "";
            returnString += transport.showDate ? new Date().toLocaleDateString() + " " + new Date().toLocaleTimeString() + " - " : "";
            returnString += transport.showLoglevel ? enums_1.ELoglevel[loglevel] + " - " : "";
            returnString += transport.showBaseComment ? transport.baseComment.toString() + " - " : "";
            for (var _i = 0, args_1 = args; _i < args_1.length; _i++) {
                var arg = args_1[_i];
                returnString += typeof (arg) === "string" ? arg : "" + JSON.stringify(arg);
            }
            return returnString;
        }
        catch (error) {
            console.error("error in configure output in logger: ", error);
            return "ERROR, check config and input";
        }
    };
    return Logger;
}());
exports.Logger = Logger;
//# sourceMappingURL=index.js.map