"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
//#region
var chai = require("chai");
var index_1 = require("../src/index");
var enums_1 = require("../src/utils/enums");
var fs_1 = require("fs");
//#endregion
describe("checks the Logger with no additional input while declaration", function () {
    var logger = new index_1.Logger();
    describe("logger.info(\"test\")", function () {
        it("should return \"INFO - test\"", function (done) {
            chai.expect(logger.info("test")).to.equal("INFO - test");
            done();
        });
    });
    describe("logger.debug(\"test\")", function () {
        it("should return \"DEBUG - test\"", function (done) {
            chai.expect(logger.debug("test")).to.equal("DEBUG - test");
            done();
        });
    });
    describe("logger.error(\"test\")", function () {
        it("should return \"ERROR - test\"", function (done) {
            chai.expect(logger.error("test")).to.equal("ERROR - test");
            done();
        });
    });
    describe("logger.trace(\"test\")", function () {
        it("should return \"TRACE - test\"", function (done) {
            chai.expect(logger.trace("test")).to.equal("TRACE - test");
            done();
        });
    });
    describe("logger.warn(\"test\")", function () {
        it("should return \"WARN - test\"", function (done) {
            chai.expect(logger.warn("test")).to.equal("WARN - test");
            done();
        });
    });
});
describe("checks the Logger with baseComment, loglevel, type, showBaseComment, showDate, showLoglevel", function () {
    var logger = new index_1.Logger({
        transports: [
            {
                baseComment: "index.ts",
                loglvl: enums_1.ELoglevel.INFO,
                type: enums_1.ETransportType.console,
                showBaseComment: true,
                showDate: true,
                showLoglevel: true
            }
        ]
    });
    describe("logger.info(\"test\")", function () {
        it("should return \"" + new Date().toLocaleDateString() + " " + new Date().toLocaleTimeString() + " - INFO - index.ts - test\"", function (done) {
            chai.expect(logger.info("test"))
                .to.equal(new Date().toLocaleDateString() + " " + new Date().toLocaleTimeString() + " - INFO - index.ts - test");
            done();
        });
    });
});
xdescribe("check if logger logs to fs", function () {
    var logger = new index_1.Logger({
        transports: [
            {
                baseComment: "index.ts",
                loglvl: enums_1.ELoglevel.INFO,
                type: enums_1.ETransportType.filesystem,
                showBaseComment: true,
                showDate: true,
                showLoglevel: true
            }
        ]
    });
    describe("logger.info(\"test\")", function () {
        var string = new Date().toLocaleDateString() + " " + new Date().toLocaleTimeString() + " - INFO - index.ts - test\"";
        logger.info("test");
        it("should return " + string, function (done) {
            var output = fs_1.readFileSync(process.env.appdata ? process.env.appdata + "/tf_log/test.log" : "/var/log/tf_log/test.log");
            chai.expect(output)
                .to.equal(string);
            done();
        });
    });
});
describe("check if logger logs to fs", function () {
    var logger = new index_1.Logger({
        transports: [
            {
                baseComment: "index.ts",
                loglvl: enums_1.ELoglevel.INFO,
                logpath: "%appdata%/tf_log/testfolder",
                logFileName: "testing",
                type: enums_1.ETransportType.filesystem,
                showBaseComment: true,
                showDate: true,
                showLoglevel: true
            }
        ]
    });
    describe("logger.info(\"test\")", function () {
        var string = new Date().toLocaleDateString() + " " + new Date().toLocaleTimeString() + " - INFO - index.ts - test\"";
        logger.info("test");
        it("should return " + string, function (done) {
            var output = fs_1.readFileSync(process.env.appdata ? process.env.appdata + "/tf_log/testing.log" : "/var/log/tf_log/testing.log");
            chai.expect(output)
                .to.equal(string);
            done();
        });
    });
});
//# sourceMappingURL=index-test.js.map